@@ -70,4 +70,4 @@ class SKOSKnowledgeParser(KnowledgeParserBase):
 
     @classmethod
     def get_extensions(cls) -> List[str]:
-        return ["xml", "zip", "rdf", "jsonld", "ttl", "nt", "n3"]
\ No newline at end of file
+        return ["xml", "zip", "rdf", "skos", "jsonld", "ttl", "nt", "n3"]
\ No newline at end of file
